#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ITRUNC_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ITRUNC_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/itrunc.hpp>

#endif
